Message of the Day Extension
============================

Overview
--------

This extension allows an administrator to display a message to all visitors to
that Review Board server. This can be used to announce incoming downtime, or a
recent upgrade. It can also contain links and other HTML formatting.

Users can dismiss the message, and it won't show up again for that particular
browser, unless cookies are cleared, or a new message is posted.


Status
------

This extension is new, but should be usable in a production environment.


Requirements
------------

This requires Review Board 2.0 beta 2 or higher.
